@@ -4,7 +4,6 @@
 //! # Arguments
 //!
 //! * The current session representing the passive role
-//! * The dual of the name of the head of the stack of the active role
 //! * The index of the binary channel among the two of the passive role
 //!
 //! # Example
@@ -16,48 +15,40 @@
 //! // If A is the current receiving role,
 //! // then its binary channel with B is the first
 //! // one.
-//! mpst_seq::recv_all_aux_simple!(s, RoleAlltoB, 1)()
+//! mpst_seq::recv_all_aux_simple!(s, 1)()
 //! ```
 
+use proc_macro2::TokenStream;
 use quote::{format_ident, quote};
 use syn::parse::{Parse, ParseStream};
-use syn::{Result, Token};
+use syn::{Expr, LitInt, Result, Token};
 
 #[derive(Debug)]
-pub struct RecvAllAuxSimpleMacroInput {
-    session: syn::Expr,
-    role: syn::Ident,
+pub struct RecvAllAuxSimple {
+    session: Expr,
     exclusion: u64,
 }
 
-impl Parse for RecvAllAuxSimpleMacroInput {
+impl Parse for RecvAllAuxSimple {
     fn parse(input: ParseStream) -> Result<Self> {
-        let session = syn::Expr::parse(input)?;
+        let session = Expr::parse(input)?;
         <Token![,]>::parse(input)?;
 
-        let role = syn::Ident::parse(input)?; // Retrive the role
-        <Token![,]>::parse(input)?;
+        let exclusion = (LitInt::parse(input)?).base10_parse::<u64>().unwrap(); // Retrive the index
 
-        let exclusion = (syn::LitInt::parse(input)?).base10_parse::<u64>().unwrap(); // Retrive the index
-
-        Ok(RecvAllAuxSimpleMacroInput {
-            session,
-            role,
-            exclusion,
-        })
+        Ok(RecvAllAuxSimple { session, exclusion })
     }
 }
 
-impl From<RecvAllAuxSimpleMacroInput> for proc_macro2::TokenStream {
-    fn from(input: RecvAllAuxSimpleMacroInput) -> proc_macro2::TokenStream {
+impl From<RecvAllAuxSimple> for TokenStream {
+    fn from(input: RecvAllAuxSimple) -> TokenStream {
         input.expand()
     }
 }
 
-impl RecvAllAuxSimpleMacroInput {
-    fn expand(&self) -> proc_macro2::TokenStream {
+impl RecvAllAuxSimple {
+    fn expand(&self) -> TokenStream {
         let session = self.session.clone();
-        let role = self.role.clone();
         let recv_session = format_ident!("session{}", self.exclusion);
 
         let mut new_sessions = Vec::new();
@@ -77,18 +68,7 @@ impl RecvAllAuxSimpleMacroInput {
 
                 let (v, new_session) = crate::binary::recv::recv( #session.#recv_session )?;
 
-                let (new_stack_left, _new_stack_right) = { // new_stack_right = new_stack_left
-                    fn temp(r: #role<crate::role::end::RoleEnd, crate::role::end::RoleEnd>)
-                    -> (crate::role::end::RoleEnd, crate::role::end::RoleEnd)
-                    {
-                        let (here1, there1) = <crate::role::end::RoleEnd as crate::role::Role>::new();
-                        let (here2, there2) = <crate::role::end::RoleEnd as crate::role::Role>::new();
-                        r.sender1.send(there1).unwrap_or(());
-                        r.sender2.send(there2).unwrap_or(());
-                        (here1, here2)
-                    }
-                    temp(#session.stack)
-                };
+                let new_stack_left = #session.stack.continuation_left();
 
                 Ok((
                     v,
