@@ -7,50 +7,72 @@ use syn::parse_macro_input;
 
 mod functionmpst;
 
-use functionmpst::recv_all_aux_simple::RecvAllAuxSimpleMacroInput;
-use functionmpst::recv_aux_simple::RecvAuxSimpleMacroInput;
-use functionmpst::send_aux_simple::SendAuxSimpleMacroInput;
+use functionmpst::recv_all_aux_simple::RecvAllAuxSimple;
+use functionmpst::recv_aux_simple::RecvAuxSimple;
+use functionmpst::send_aux_simple::SendAuxSimple;
 
-mod macros;
+mod choose_mpst_multi_to_all;
 
-use macros::baking::BakingMacroInput;
-use macros::baking_with_enum::BakingWithEnumMacroInput;
-use macros::create_broadcast_role_short::CreateBroadcastRoleShortMacroInput;
-use macros::create_normal_role_short::CreateNormalRoleShortMacroInput;
-use macros::multiple::broadcast_cancel::BroadcastCancelMacroInput;
-use macros::multiple::checking::CheckingInput;
-use macros::multiple::choose::choose_mpst_create_multi_to_all::ChooseMultiCreateToAllMacroInput;
-use macros::multiple::choose::choose_mpst_multi_cancel_to_all::ChooseTypeMultiCancelToAllMacroInput;
-use macros::multiple::choose::choose_mpst_multi_http_to_all::ChooseTypeMultiHttpToAllMacroInput;
-use macros::multiple::choose::choose_mpst_multi_to_all::ChooseMultiToAllMacroInput;
-use macros::multiple::choose::create_choose_mpst_session_multi_left::ChooseTypeMultiLeftMacroInput;
-use macros::multiple::choose::create_choose_mpst_session_multi_right::ChooseTypeMultiRightMacroInput;
-use macros::multiple::choose::create_choose_type_multi::ChooseTypeMultiMacroInput;
-use macros::multiple::choose::create_fn_choose_mpst_cancel_multi_to_all_bundle::ChooseTypeCancelMultiToAllBundleMacroInput;
-use macros::multiple::choose::create_fn_choose_mpst_multi_to_all_bundle::ChooseTypeMultiToAllBundleMacroInput;
-use macros::multiple::close::close_mpst::CloseMpstMacroInput;
-use macros::multiple::close::close_mpst_cancel::CloseMpstCancelMacroInput;
-use macros::multiple::close::close_mpst_check_cancel::CloseMpstCheckCancelMacroInput;
-use macros::multiple::create_meshedchannels::CreateMeshedChannelsMacroInput;
-use macros::multiple::fork_mpst_multi::ForkMPSTMultiMacroInput;
-use macros::multiple::offer::create_offer_mpst_session_multi::OfferMPSTSessionMultiMacroInput;
-use macros::multiple::offer::create_offer_type_multi::OfferTypeMultiMacroInput;
-use macros::multiple::recv::create_recv_http_session::CreateRecvHttpSessionMacroInput;
-use macros::multiple::recv::create_recv_mpst_all_session::CreateRecvMPSTAllSessionMacroInput;
-use macros::multiple::recv::create_recv_mpst_session::CreateRecvMPSTSessionMacroInput;
-use macros::multiple::recv::recv_mpst::RecvMPSTMacroInput;
-use macros::multiple::send::create_send_check_cancel::CreateSendCheckCancelMacroInput;
-use macros::multiple::send::create_send_http_session::CreateSendHttpSessionMacroInput;
-use macros::multiple::send::create_send_mpst_cancel::CreateSendMPSTCancelMacroInput;
-use macros::multiple::send::create_send_mpst_session::CreateSendMPSTSessionMacroInput;
-use macros::multiple::send::send_cancel::SendCancelMacroInput;
-use macros::multiple::send::send_mpst::SendMPSTMacroInput;
+use choose_mpst_multi_to_all::ChooseMultiToAll;
+
+mod macros_simple;
+
+use macros_simple::offer::create_offer_mpst_session_multi::OfferMPSTSessionMulti;
+use macros_simple::recv::create_recv_mpst_session::CreateRecvMPSTSession;
+use macros_simple::roles::create_broadcast_role_short::CreateBroadcastRoleShort;
+use macros_simple::roles::create_normal_role_short::CreateNormalRoleShort;
+use macros_simple::send::create_send_mpst_session::CreateSendMPSTSession;
+
+mod macros_multiple;
+
+use macros_multiple::multiple::broadcast_cancel::BroadcastCancel;
+use macros_multiple::multiple::choose::choose_mpst_create_multi_to_all::ChooseMultiCreateToAll;
+use macros_multiple::multiple::choose::choose_mpst_multi_cancel_to_all::ChooseTypeMultiCancelToAll;
+use macros_multiple::multiple::choose::create_choose_mpst_session_multi_left::ChooseTypeMultiLeft;
+use macros_multiple::multiple::choose::create_choose_mpst_session_multi_right::ChooseTypeMultiRight;
+use macros_multiple::multiple::choose::create_choose_type_multi::ChooseTypeMulti;
+use macros_multiple::multiple::choose::create_fn_choose_mpst_cancel_multi_to_all_bundle::ChooseTypeCancelMultiToAllBundle;
+use macros_multiple::multiple::choose::create_fn_choose_mpst_multi_to_all_bundle::ChooseTypeMultiToAllBundle;
+use macros_multiple::multiple::close::close_mpst::CloseMpst;
+use macros_multiple::multiple::close::close_mpst_cancel::CloseMpstCancel;
+use macros_multiple::multiple::close::close_mpst_check_cancel::CloseMpstCheckCancel;
+use macros_multiple::multiple::create_meshedchannels::CreateMeshedChannels;
+use macros_multiple::multiple::fork_mpst_multi::ForkMPSTMulti;
+use macros_multiple::multiple::offer::create_offer_type_multi::OfferTypeMulti;
+use macros_multiple::multiple::send::create_send_check_cancel::CreateSendCheckCancel;
+use macros_multiple::multiple::send::create_send_mpst_cancel::CreateSendMPSTCancel;
+use macros_multiple::multiple::send::send_cancel::SendCancel;
+
+mod interleaved;
+
+use interleaved::close_mpst_interleaved::CloseMpstInterleaved;
+use interleaved::fork_mpst_multi_interleaved::ForkMPSTMultiInterleaved;
+use interleaved::fork_mpst_multi_solo::ForkMPSTMultiSolo;
+
+mod macros_http;
+
+use macros_http::choose::choose_mpst_multi_http_to_all::ChooseTypeMultiHttpToAll;
+use macros_http::recv::create_recv_http_session::CreateRecvHttpSession;
+use macros_http::send::create_send_http_session::CreateSendHttpSession;
+
+mod checking;
+
+use checking::aux_checking::CheckingInput;
+use checking::branching::branching_variants;
+
+mod baking;
+
+use baking::baking_basic::Baking;
+use baking::baking_interleaved_with_enum_and_cancel::BakingInterleavedWithEnumAndCancel;
+use baking::baking_with_cancel::BakingWithCancel;
+use baking::baking_with_enum::BakingWithEnum;
+use baking::baking_with_enum_and_cancel::BakingWithEnumAndCancel;
 
 //////////////////////////////////////
 
 #[proc_macro]
 pub fn recv_aux_simple(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as RecvAuxSimpleMacroInput);
+    let input = parse_macro_input!(input as RecvAuxSimple);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -64,7 +86,7 @@ pub fn e_recv_aux_simple(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn recv_all_aux_simple(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as RecvAllAuxSimpleMacroInput);
+    let input = parse_macro_input!(input as RecvAllAuxSimple);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -78,7 +100,7 @@ pub fn e_recv_all_aux_simple(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn send_aux_simple(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as SendAuxSimpleMacroInput);
+    let input = parse_macro_input!(input as SendAuxSimple);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -91,36 +113,22 @@ pub fn e_send_aux_simple(input: TokenStream) -> TokenStream {
 //////////////////////////////////////
 
 #[proc_macro]
-pub fn send_cancel(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as SendCancelMacroInput);
+pub fn choose_mpst_multi_to_all(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as ChooseMultiToAll);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
 
 #[proc_macro_hack]
-pub fn e_send_cancel(input: TokenStream) -> TokenStream {
-    send_cancel(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn broadcast_cancel(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as BroadcastCancelMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_broadcast_cancel(input: TokenStream) -> TokenStream {
-    broadcast_cancel(input)
+pub fn e_choose_mpst_multi_to_all(input: TokenStream) -> TokenStream {
+    choose_mpst_multi_to_all(input)
 }
 
 //////////////////////////////////////
 
 #[proc_macro]
 pub fn create_normal_role_short(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateNormalRoleShortMacroInput);
+    let input = parse_macro_input!(input as CreateNormalRoleShort);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -134,7 +142,7 @@ pub fn e_create_normal_role_short(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn create_broadcast_role_short(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateBroadcastRoleShortMacroInput);
+    let input = parse_macro_input!(input as CreateBroadcastRoleShort);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -147,22 +155,78 @@ pub fn e_create_broadcast_role_short(input: TokenStream) -> TokenStream {
 //////////////////////////////////////
 
 #[proc_macro]
-pub fn baking(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as BakingMacroInput);
+pub fn create_offer_mpst_session_multi(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as OfferMPSTSessionMulti);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
 
 #[proc_macro_hack]
-pub fn e_baking(input: TokenStream) -> TokenStream {
-    baking(input)
+pub fn e_create_offer_mpst_session_multi(input: TokenStream) -> TokenStream {
+    create_offer_mpst_session_multi(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn create_recv_mpst_session(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as CreateRecvMPSTSession);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_create_recv_mpst_session(input: TokenStream) -> TokenStream {
+    create_recv_mpst_session(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn create_send_mpst_session(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as CreateSendMPSTSession);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_create_send_mpst_session(input: TokenStream) -> TokenStream {
+    create_send_mpst_session(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn send_cancel(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as SendCancel);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_send_cancel(input: TokenStream) -> TokenStream {
+    send_cancel(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn broadcast_cancel(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as BroadcastCancel);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_broadcast_cancel(input: TokenStream) -> TokenStream {
+    broadcast_cancel(input)
 }
 
 //////////////////////////////////////
 
 #[proc_macro]
 pub fn close_mpst(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CloseMpstMacroInput);
+    let input = parse_macro_input!(input as CloseMpst);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -176,7 +240,7 @@ pub fn e_close_mpst(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn close_mpst_check_cancel(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CloseMpstCheckCancelMacroInput);
+    let input = parse_macro_input!(input as CloseMpstCheckCancel);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -190,7 +254,7 @@ pub fn e_close_mpst_check_cancel(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn fork_mpst_multi(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ForkMPSTMultiMacroInput);
+    let input = parse_macro_input!(input as ForkMPSTMulti);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -204,7 +268,7 @@ pub fn e_fork_mpst_multi(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn create_choose_type_multi(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseTypeMultiMacroInput);
+    let input = parse_macro_input!(input as ChooseTypeMulti);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -218,7 +282,7 @@ pub fn e_create_choose_type_multi(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn create_choose_mpst_session_multi_left(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseTypeMultiLeftMacroInput);
+    let input = parse_macro_input!(input as ChooseTypeMultiLeft);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -232,7 +296,7 @@ pub fn e_create_choose_mpst_session_multi_left(input: TokenStream) -> TokenStrea
 
 #[proc_macro]
 pub fn create_choose_mpst_session_multi_right(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseTypeMultiRightMacroInput);
+    let input = parse_macro_input!(input as ChooseTypeMultiRight);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -244,23 +308,9 @@ pub fn e_create_choose_mpst_session_multi_right(input: TokenStream) -> TokenStre
 
 //////////////////////////////////////
 
-#[proc_macro]
-pub fn choose_mpst_multi_to_all(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseMultiToAllMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_choose_mpst_multi_to_all(input: TokenStream) -> TokenStream {
-    choose_mpst_multi_to_all(input)
-}
-
-//////////////////////////////////////
-
 #[proc_macro]
 pub fn choose_mpst_multi_cancel_to_all(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseTypeMultiCancelToAllMacroInput);
+    let input = parse_macro_input!(input as ChooseTypeMultiCancelToAll);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -272,23 +322,9 @@ pub fn e_choose_mpst_multi_cancel_to_all(input: TokenStream) -> TokenStream {
 
 //////////////////////////////////////
 
-#[proc_macro]
-pub fn choose_mpst_multi_http_to_all(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseTypeMultiHttpToAllMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_choose_mpst_multi_http_to_all(input: TokenStream) -> TokenStream {
-    choose_mpst_multi_http_to_all(input)
-}
-
-//////////////////////////////////////
-
 #[proc_macro]
 pub fn create_fn_choose_mpst_multi_to_all_bundle(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseTypeMultiToAllBundleMacroInput);
+    let input = parse_macro_input!(input as ChooseTypeMultiToAllBundle);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -302,7 +338,7 @@ pub fn e_create_fn_choose_mpst_multi_to_all_bundle(input: TokenStream) -> TokenS
 
 #[proc_macro]
 pub fn create_fn_choose_mpst_cancel_multi_to_all_bundle(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseTypeCancelMultiToAllBundleMacroInput);
+    let input = parse_macro_input!(input as ChooseTypeCancelMultiToAllBundle);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -316,7 +352,7 @@ pub fn e_create_fn_choose_mpst_cancel_multi_to_all_bundle(input: TokenStream) ->
 
 #[proc_macro]
 pub fn create_offer_type_multi(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as OfferTypeMultiMacroInput);
+    let input = parse_macro_input!(input as OfferTypeMulti);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -328,121 +364,9 @@ pub fn e_create_offer_type_multi(input: TokenStream) -> TokenStream {
 
 //////////////////////////////////////
 
-#[proc_macro]
-pub fn create_offer_mpst_session_multi(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as OfferMPSTSessionMultiMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_create_offer_mpst_session_multi(input: TokenStream) -> TokenStream {
-    create_offer_mpst_session_multi(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn recv_mpst(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as RecvMPSTMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_recv_mpst(input: TokenStream) -> TokenStream {
-    recv_mpst(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn create_recv_mpst_session(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateRecvMPSTSessionMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_create_recv_mpst_session(input: TokenStream) -> TokenStream {
-    create_recv_mpst_session(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn create_recv_http_session(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateRecvHttpSessionMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_create_recv_http_session(input: TokenStream) -> TokenStream {
-    create_recv_http_session(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn create_recv_mpst_all_session(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateRecvMPSTAllSessionMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_create_recv_mpst_all_session(input: TokenStream) -> TokenStream {
-    create_recv_mpst_all_session(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn send_mpst(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as SendMPSTMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_send_mpst(input: TokenStream) -> TokenStream {
-    send_mpst(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn create_send_mpst_session(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateSendMPSTSessionMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_create_send_mpst_session(input: TokenStream) -> TokenStream {
-    create_send_mpst_session(input)
-}
-
-//////////////////////////////////////
-
-#[proc_macro]
-pub fn create_send_http_session(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateSendHttpSessionMacroInput);
-    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
-    output.into()
-}
-
-#[proc_macro_hack]
-pub fn e_create_send_http_session(input: TokenStream) -> TokenStream {
-    create_send_http_session(input)
-}
-
-//////////////////////////////////////
-
 #[proc_macro]
 pub fn create_send_mpst_cancel(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateSendMPSTCancelMacroInput);
+    let input = parse_macro_input!(input as CreateSendMPSTCancel);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -456,7 +380,7 @@ pub fn e_create_send_mpst_cancel(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn create_send_check_cancel(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateSendCheckCancelMacroInput);
+    let input = parse_macro_input!(input as CreateSendCheckCancel);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -470,7 +394,7 @@ pub fn e_create_send_check_cancel(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn create_meshedchannels(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CreateMeshedChannelsMacroInput);
+    let input = parse_macro_input!(input as CreateMeshedChannels);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -484,7 +408,7 @@ pub fn e_create_meshedchannels(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn close_mpst_cancel(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as CloseMpstCancelMacroInput);
+    let input = parse_macro_input!(input as CloseMpstCancel);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -498,7 +422,7 @@ pub fn e_close_mpst_cancel(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn choose_mpst_create_multi_to_all(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as ChooseMultiCreateToAllMacroInput);
+    let input = parse_macro_input!(input as ChooseMultiCreateToAll);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
@@ -511,15 +435,71 @@ pub fn e_choose_mpst_create_multi_to_all(input: TokenStream) -> TokenStream {
 //////////////////////////////////////
 
 #[proc_macro]
-pub fn baking_with_enum(input: TokenStream) -> TokenStream {
-    let input = parse_macro_input!(input as BakingWithEnumMacroInput);
+pub fn fork_mpst_multi_solo(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as ForkMPSTMultiSolo);
     let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
     output.into()
 }
 
 #[proc_macro_hack]
-pub fn e_baking_with_enum(input: TokenStream) -> TokenStream {
-    baking_with_enum(input)
+pub fn e_fork_mpst_multi_solo(input: TokenStream) -> TokenStream {
+    fork_mpst_multi_solo(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn close_mpst_interleaved(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as CloseMpstInterleaved);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_close_mpst_interleaved(input: TokenStream) -> TokenStream {
+    close_mpst_interleaved(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn choose_mpst_multi_http_to_all(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as ChooseTypeMultiHttpToAll);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_choose_mpst_multi_http_to_all(input: TokenStream) -> TokenStream {
+    choose_mpst_multi_http_to_all(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn create_recv_http_session(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as CreateRecvHttpSession);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_create_recv_http_session(input: TokenStream) -> TokenStream {
+    create_recv_http_session(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn create_send_http_session(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as CreateSendHttpSession);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_create_send_http_session(input: TokenStream) -> TokenStream {
+    create_send_http_session(input)
 }
 
 //////////////////////////////////////
@@ -535,3 +515,102 @@ pub fn checking(input: TokenStream) -> TokenStream {
 pub fn e_checking(input: TokenStream) -> TokenStream {
     checking(input)
 }
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn baking(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as Baking);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_baking(input: TokenStream) -> TokenStream {
+    baking(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn baking_with_enum(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as BakingWithEnum);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_baking_with_enum(input: TokenStream) -> TokenStream {
+    baking_with_enum(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn baking_with_cancel(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as BakingWithCancel);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_baking_with_cancel(input: TokenStream) -> TokenStream {
+    baking_with_cancel(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn baking_with_enum_and_cancel(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as BakingWithEnumAndCancel);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_baking_with_enum_and_cancel(input: TokenStream) -> TokenStream {
+    baking_with_enum_and_cancel(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn fork_mpst_multi_interleaved(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as ForkMPSTMultiInterleaved);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_fork_mpst_multi_interleaved(input: TokenStream) -> TokenStream {
+    fork_mpst_multi_interleaved(input)
+}
+
+//////////////////////////////////////
+
+#[proc_macro_attribute]
+pub fn branching(args: TokenStream, input: TokenStream) -> TokenStream {
+    let mut out = input.clone();
+
+    let ty = parse_macro_input!(input as syn::Item);
+    assert!(args.is_empty());
+
+    if let Err(e) = branching_variants(ty) {
+        out.extend(TokenStream::from(e.to_compile_error()));
+    }
+    out
+}
+
+//////////////////////////////////////
+
+#[proc_macro]
+pub fn baking_interleaved_with_enum_and_cancel(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as BakingInterleavedWithEnumAndCancel);
+    let output: proc_macro2::TokenStream = proc_macro2::TokenStream::from(input);
+    output.into()
+}
+
+#[proc_macro_hack]
+pub fn e_baking_interleaved_with_enum_and_cancel(input: TokenStream) -> TokenStream {
+    baking_interleaved_with_enum_and_cancel(input)
+}
